@@ -18,7 +18,6 @@
 """The Tuskar Service API."""
 
 import logging
-import os
 import sys
 from wsgiref import simple_server
 
@@ -47,18 +46,6 @@ def main(argv=None):
     LOG.info("Serving on http://%s:%s" % (host, port))
     LOG.info("Configuration:")
     cfg.CONF.log_opt_values(LOG, logging.INFO)
-    # make sure we have tripleo-heat-templates:
-    heat_template_path = cfg.CONF.tht_local_dir
-    try:
-        os.listdir(heat_template_path)
-    except OSError:
-        LOG.info(
-            "Can't find local tripleo-heat-template files at %s"
-            % (heat_template_path))
-        LOG.info(
-            "Cannot proceed - missing tripleo heat templates "
-            "See INSTALL documentation for more info")
-    LOG.info("Using tripleo-heat-templates at %s" % (heat_template_path))
 
     try:
         wsgi.serve_forever()
