@@ -16,17 +16,14 @@
 #    under the License.
 
 from oslo.config import cfg
+from oslo.db import options as db_options
 
-from tuskar.common import paths
-from tuskar.openstack.common.db.sqlalchemy import session as db_session
 from tuskar import version
 
-_DEFAULT_SQL_CONNECTION = 'sqlite:///' + paths.state_path_def('$sqlite_db')
-
 
 def parse_args(argv, default_config_files=None):
-    db_session.set_defaults(sql_connection=_DEFAULT_SQL_CONNECTION,
-                            sqlite_db='tuskar.sqlite')
+    db_options.set_defaults(cfg.CONF, sqlite_db='tuskar.sqlite')
+
     cfg.CONF(argv[1:],
              project='tuskar',
              version=version.version_info.release_string(),
