@@ -21,16 +21,16 @@ from tuskar.tests.base import TestCase
 
 class LoadRoleTests(TestCase):
 
-    @patch('tuskar.storage.load_roles._list_roles',
-           return_value=[['role_name.yaml', '/path/role_name.yaml']])
     @patch('tuskar.storage.load_roles._load_file', return_value="YAML")
     @patch('tuskar.cmd.load_roles._print_names')
-    def test_main(self, mock_print, mock_read, mock_list):
+    def test_main(self, mock_print, mock_read):
 
         # test
-        load_roles.main(argv="--master-seed=seed.yaml path".split())
+        load_roles.main(argv=(
+            "--master-seed=seed.yaml -r role_name1.yaml "
+            "-r /path/role_name2.yaml").split())
 
         # verify
         self.assertEqual([
-            call('Created', ['role_name.yaml'])
+            call('Created', ['role_name1', 'role_name2'])
         ], mock_print.call_args_list)
